Welcome to ClientVPS Mirrors

Help for package spuriouscorrelations
Title: Datasets with Strong and Spurious Correlations
Version: 0.1
Description: Provides datasets from Vigen (2015) https://web.archive.org/web/20230607181247/https%3A/tylervigen.com/spurious-correlations rescued from the Internet Wayback Machine. These should be preserved for statistics introductory courses as these make it very clear that correlation is not causation.
License: CC0
Encoding: UTF-8
RoxygenNote: 7.3.2
Depends: R (≥ 2.10)
LazyData: true
NeedsCompilation: no
Packaged: 2025-09-21 13:40:21 UTC; pacha
Author: Tyler Vigen [cph], Mauricio Vargas Sepulveda ORCID iD [aut, cre]
Maintainer: Mauricio Vargas Sepulveda <m.vargas.sepulveda@gmail.com>
Repository: CRAN
Date/Publication: 2025-09-27 08:30:02 UTC

Spurious Correlations datasets

Description

A dataset to preserve tylervigen.com correlations.

Usage

spurious_correlations

Format

A tibbles with 155 observations and 9 variables:

year

Year

var1

Variable 1

var2

Variable 2

var1_short

Variable 1 short name

var2_short

Variable 2 short name

var1_unit

Variable 1 unit

var2_unit

Variable 2 unit

var1_value

Variable 1 value

var2_value

Variable 2 value

source

https://web.archive.org/web/20230607181247/https://tylervigen.com/spurious-correlations

Examples

# Drownings by Falling into a Pool
# correlates with
# Films Nicolas Cage Appeared In
d <- spurious_correlations[spurious_correlations$var2_short == "Nicholas Cage", ]
cor(d$var1_value, d$var2_value)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.